Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9993)

Unified Diff: chrome/renderer/net/net_error_helper.cc

Issue 2775963002: s/same_page/same_document for DidCommitProvisionalLoad method. (Closed)
Patch Set: Addressed review comment Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/renderer/net/net_error_helper.cc
diff --git a/chrome/renderer/net/net_error_helper.cc b/chrome/renderer/net/net_error_helper.cc
index b55941f8d671c71af654d3a78fd1640729b11fde..cd92261e48efc6c9ebba2b9f09d44f40f9cbbff7 100644
--- a/chrome/renderer/net/net_error_helper.cc
+++ b/chrome/renderer/net/net_error_helper.cc
@@ -124,11 +124,12 @@ void NetErrorHelper::DidStartProvisionalLoad(
GetLoadingPageType(data_source));
}
-void NetErrorHelper::DidCommitProvisionalLoad(bool is_new_navigation,
- bool is_same_page_navigation) {
- // If this is a "same page" navigation, it's not a real navigation. There
+void NetErrorHelper::DidCommitProvisionalLoad(
+ bool is_new_navigation,
+ bool is_same_document_navigation) {
+ // If this is a "same-document" navigation, it's not a real navigation. There
// wasn't a start event for it, either, so just ignore it.
- if (is_same_page_navigation)
+ if (is_same_document_navigation)
return;
// Invalidate weak pointers from old error page controllers. If loading a new
« no previous file with comments | « chrome/renderer/net/net_error_helper.h ('k') | chrome/renderer/page_load_metrics/metrics_render_frame_observer.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698